@@ -443,13 +443,13 @@ def release_inputs_by_collection_old(to_release_inputs):
             to_release_names_missing = []
             for to_release_content in to_release_contents:
                 if (to_release_content['status'] in [ContentStatus.Available]            # noqa: W503
-                    or to_release_content['substatus'] in [ContentStatus.Available]):    # noqa: W503
+                   or to_release_content['substatus'] in [ContentStatus.Available]):    # noqa: W503
                     to_release_names_available.append(to_release_content['name'])
                 elif (to_release_content['status'] in [ContentStatus.FakeAvailable]            # noqa: W503
-                      or to_release_content['substatus'] in [ContentStatus.FakeAvailable]):    # noqa: W503
+                     or to_release_content['substatus'] in [ContentStatus.FakeAvailable]):    # noqa: W503, E128
                     to_release_names_fake_available.append(to_release_content['name'])
                 elif (to_release_content['status'] in [ContentStatus.FinalFailed]            # noqa: W503
-                      or to_release_content['substatus'] in [ContentStatus.FinalFailed]):    # noqa: W503
+                     or to_release_content['substatus'] in [ContentStatus.FinalFailed]):    # noqa: W503, E128
                     to_release_names_final_failed.append(to_release_content['name'])
                 elif (to_release_content['status'] in [ContentStatus.Missing]            # noqa: W503
                       or to_release_content['substatus'] in [ContentStatus.Missing]):    # noqa: W503
@@ -461,7 +461,7 @@ def release_inputs_by_collection_old(to_release_inputs):
             for content in contents:
                 if (content['content_relation_type'] == ContentRelationType.InputDependency):    # noqa: W503
                     if (content['status'] not in [ContentStatus.Available]                       # noqa: W503
-                        and content['name'] in to_release_names_available):                          # noqa: W503
+                       and content['name'] in to_release_names_available):                          # noqa: W503
                         update_content = {'content_id': content['content_id'],
                                           'substatus': ContentStatus.Available,
                                           'status': ContentStatus.Available}
@@ -610,7 +610,7 @@ def get_work_name_to_coll_map(request_id):
     work_name_to_coll_map = {}
     for tf in tfs:
         if ('transform_metadata' in tf and tf['transform_metadata']
-            and 'work_name' in tf['transform_metadata'] and tf['transform_metadata']['work_name']):  # noqa: W503
+           and 'work_name' in tf['transform_metadata'] and tf['transform_metadata']['work_name']):  # noqa: W503
             work_name = tf['transform_metadata']['work_name']
             transform_id = tf['transform_id']
             if work_name not in work_name_to_coll_map:
